# json-data-type-transcompiler

Interprets data types schema for programming languages from a given JSON object.

A web interface for using this library is provided at <a href="https://devtools.joeyshi.xyz">devtools.joeyshi.xyz</a>
